/**
 * Copyright (c) 2016, The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package android.net.wifi.hotspot2.pps;

import java.util.Collection;

/**
 * Class representing HomeSP subtree in PerProviderSubscription (PPS)
 * Management Object (MO) tree.
 *
 * For more info, refer to Hotspot 2.0 PPS MO defined in section 9.1 of the Hotspot 2.0
 * Release 2 Technical Specification.
 */

@SuppressWarnings({"unchecked", "deprecation", "all"})
public final class HomeSp implements android.os.Parcelable {

/**
 * Constructor for creating HomeSp with default values.
 */

public HomeSp() { throw new RuntimeException("Stub!"); }

/**
 * Copy constructor.
 *
 * @param source The source to copy from
 */

public HomeSp(android.net.wifi.hotspot2.pps.HomeSp source) { throw new RuntimeException("Stub!"); }

/**
 * Set the FQDN (Fully Qualified Domain Name) associated with this home service provider.
 *
 * @param fqdn The FQDN to set to
 */

public void setFqdn(java.lang.String fqdn) { throw new RuntimeException("Stub!"); }

/**
 * Get the FQDN (Fully Qualified Domain Name) associated with this home service provider.
 *
 * @return the FQDN associated with this home service provider
 */

public java.lang.String getFqdn() { throw new RuntimeException("Stub!"); }

/**
 * Set the friendly name associated with this home service provider.
 *
 * @param friendlyName The friendly name to set to
 */

public void setFriendlyName(java.lang.String friendlyName) { throw new RuntimeException("Stub!"); }

/**
 * Get the friendly name associated with this home service provider.
 *
 * @return the friendly name associated with this home service provider
 */

public java.lang.String getFriendlyName() { throw new RuntimeException("Stub!"); }

/**
 * Set a list of HomeOIs such that all OIs in the list must match an OI in the Roaming
 * Consortium advertised by a hotspot operator. The list set by this API will have precedence
 * over {@link #setMatchAnyOis(long[])}, meaning the list set in {@link #setMatchAnyOis(long[])}
 * will only be used for matching if the list set by this API is null or empty.
 *
 * @param matchAllOis An array of longs containing the HomeOIs
 */

public void setMatchAllOis(@android.annotation.Nullable long[] matchAllOis) { throw new RuntimeException("Stub!"); }

/**
 * Get the list of HomeOIs such that all OIs in the list must match an OI in the Roaming
 * Consortium advertised by a hotspot operator.
 *
 * @return An array of longs containing the HomeOIs
 */

@android.annotation.Nullable
public long[] getMatchAllOis() { throw new RuntimeException("Stub!"); }

/**
 * Set a list of HomeOIs such that any OI in the list matches an OI in the Roaming Consortium
 * advertised by a hotspot operator. The list set by {@link #setMatchAllOis(long[])}
 * will have precedence over this API, meaning this list will only be used for matching if the
 * list set by {@link #setMatchAllOis(long[])} is null or empty.
 *
 * @param matchAnyOis An array of longs containing the HomeOIs
 */

public void setMatchAnyOis(@android.annotation.Nullable long[] matchAnyOis) { throw new RuntimeException("Stub!"); }

/**
 * Get a list of HomeOIs such that any OI in the list matches an OI in the Roaming Consortium
 * advertised by a hotspot operator.
 *
 * @return An array of longs containing the HomeOIs
 */

@android.annotation.Nullable
public long[] getMatchAnyOis() { throw new RuntimeException("Stub!"); }

/**
 * Set the list of FQDN (Fully Qualified Domain Name) of other Home partner providers.
 *
 * @param otherHomePartners Collection of Strings containing the FQDNs of other Home partner
 *                         providers
 */

public void setOtherHomePartnersList(@android.annotation.NonNull java.util.Collection<java.lang.String> otherHomePartners) { throw new RuntimeException("Stub!"); }

/**
 * Get the list of FQDN (Fully Qualified Domain Name) of other Home partner providers set in
 * the profile.
 *
 * @return Collection of Strings containing the FQDNs of other Home partner providers set in the
 * profile
 */

@android.annotation.NonNull
public java.util.Collection<java.lang.String> getOtherHomePartnersList() { throw new RuntimeException("Stub!"); }

/**
 * Set the Organization Identifiers (OIs) identifying a roaming consortium of which this
 * provider is a member.
 *
 * @param roamingConsortiumOis Array of roaming consortium OIs
 */

public void setRoamingConsortiumOis(long[] roamingConsortiumOis) { throw new RuntimeException("Stub!"); }

/**
 * Get the Organization Identifiers (OIs) identifying a roaming consortium of which this
 * provider is a member.
 *
 * @return array of roaming consortium OIs
 */

public long[] getRoamingConsortiumOis() { throw new RuntimeException("Stub!"); }

public int describeContents() { throw new RuntimeException("Stub!"); }

public void writeToParcel(android.os.Parcel dest, int flags) { throw new RuntimeException("Stub!"); }

public boolean equals(java.lang.Object thatObject) { throw new RuntimeException("Stub!"); }

public int hashCode() { throw new RuntimeException("Stub!"); }

public java.lang.String toString() { throw new RuntimeException("Stub!"); }

@android.annotation.NonNull public static final android.os.Parcelable.Creator<android.net.wifi.hotspot2.pps.HomeSp> CREATOR;
static { CREATOR = null; }
}

